@@ -24,10 +24,12 @@ failing examples it finds.
 """
 
 
-from hypothesis._settings import settings, Verbosity, Phase, HealthCheck
+from hypothesis._settings import settings, Verbosity, Phase, HealthCheck, \
+    unlimited
 from hypothesis.version import __version_info__, __version__
 from hypothesis.control import assume, note, reject, event
 from hypothesis.core import given, find, example, seed
+from hypothesis.utils.conventions import infer
 
 
 __all__ = [
@@ -39,10 +41,12 @@ __all__ = [
     'reject',
     'seed',
     'given',
+    'unlimited',
     'find',
     'example',
     'note',
     'event',
+    'infer',
     '__version__',
     '__version_info__',
 ]
